pub struct AddressRange { /* private fields */ }Expand description
A range of addresses corresponding to some NetAddress.
The only way to create an instance of AddressRange is from a
NetAddress or Address, thus only valid ranges are represented by
this type.
This type can be used as a key in a key-value collection that uses Ord for
its keys. (NB: the equality is defined as “if the ranges overlap — they
are equal”)
Implementations